System.Hardware.Serialport
- data StopBits
- data Parity
- data FlowControl
- data BaudRate
- data SerialPort
- hOpenSerial :: String -> BaudRate -> Int -> StopBits -> Parity -> FlowControl -> IO Handle
- openSerial :: String -> BaudRate -> Int -> StopBits -> Parity -> FlowControl -> IO SerialPort
- sendChar :: SerialPort -> Char -> IO ()
- recvChar :: SerialPort -> IO (Maybe Char)
- closeSerial :: SerialPort -> IO ()
Types
data FlowControl Source
Constructors
| Software | |
| NoFlowControl |
data BaudRate
data SerialPort Source
Simple, non-portable.
Arguments
| :: String | The filename of the serial port, such as |
| -> BaudRate | |
| -> Int | The number of bits per word, typically 8 |
| -> StopBits | Almost always |
| -> Parity | Error checking |
| -> FlowControl | |
| -> IO Handle |
Open and configure a serial port and return a Handle
Portable methods.
Arguments
| :: String | The filename of the serial port, such as |
| -> BaudRate | |
| -> Int | The number of bits per word, typically 8 |
| -> StopBits | Almost always |
| -> Parity | |
| -> FlowControl | |
| -> IO SerialPort |
closeSerial :: SerialPort -> IO ()Source